Change Log for OppiaMobile Platform Components
================================================

The OppiaMobile platform consists of 3 core components (server, client app and 
the Moodle export block). This page summarises the currently released versions 
of each of these and the changelog history for each.


OppiaMobile Server (Django)
--------------------------------

Current Version: 0.5.2

.. toctree::
   :maxdepth: 2
   
   changelog_server


OppiaMobile Client App (Android)
-----------------------------------

Current Version: 48 (4.1.2)

.. toctree::
   :maxdepth: 2
   
   changelog_android
   
OppiaMobile export block for Moodle
------------------------------------- 

Current Version: v2014102900

.. toctree::
   :maxdepth: 2
   
   changelog_moodleblock